@@ -10,11 +10,12 @@ extern crate serde_derive;
 extern crate uuid;
 
 use conn::{conn_to_response, create_conn};
-pub use conn::{css, html, js, json, redirect_to, with_content_type, xml, Conn};
-use routes::match_route;
-pub use routes::{Pattern, Route};
+use routes::{add_params, match_route};
 use std::collections::HashMap;
 use wasm_bindgen::prelude::*;
+
+pub use conn::{css, html, js, json, redirect_to, with_content_type, xml, Conn};
+pub use routes::{Pattern, Route};
 pub use web::{Method, Request, Response};
 
 pub enum ConfettiError {}
@@ -55,7 +56,7 @@ async fn process_request(request_object: JsValue, routes: Vec<Route>) -> Result<
 }
 
 async fn run_route(route: &Route, conn: Conn) -> Result<Conn, ConfettiError> {
-    let mut current_conn: Conn = conn;
+    let mut current_conn: Conn = add_params(route, conn);
     let middlewares = &route.middlewares[..];
     for middleware in middlewares {
         current_conn = middleware(current_conn).await;
